@@ -5,12 +5,56 @@ package Dist::Zilla::PluginBundle::AJGB;
 BEGIN {
   $Dist::Zilla::PluginBundle::AJGB::AUTHORITY = 'cpan:AJGB';
 }
+{
+  $Dist::Zilla::PluginBundle::AJGB::VERSION = '2.01';
+}
 
 # ABSTRACT: Dist::Zilla plugins for AJGB
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+# make AutoPrereqs happy
+use Dist::Zilla::Plugin::ExecDir ();
+use Dist::Zilla::Plugin::ShareDir ();
+use Dist::Zilla::Plugin::GatherDir ();
+use Dist::Zilla::Plugin::MetaYAML ();
+use Dist::Zilla::Plugin::MetaJSON ();
+use Dist::Zilla::Plugin::License ();
+use Dist::Zilla::Plugin::Manifest ();
+use Dist::Zilla::Plugin::Test::Compile ();
+use Dist::Zilla::Plugin::PodCoverageTests ();
+use Dist::Zilla::Plugin::PodSyntaxTests ();
+use Dist::Zilla::Plugin::EOLTests ();
+use Dist::Zilla::Plugin::NoTabsTests ();
+use Dist::Zilla::Plugin::KwaliteeTests ();
+use Dist::Zilla::Plugin::Test::Portability ();
+use Dist::Zilla::Plugin::Test::Synopsis ();
+use Dist::Zilla::Plugin::PruneCruft ();
+use Dist::Zilla::Plugin::ManifestSkip ();
+use Dist::Zilla::Plugin::PkgVersion ();
+use Dist::Zilla::Plugin::Authority ();
+use Dist::Zilla::Plugin::PodWeaver ();
+use Dist::Zilla::Plugin::MetaConfig ();
+use Dist::Zilla::Plugin::AutoMetaResources ();
+use Dist::Zilla::Plugin::AutoPrereqs ();
+use Dist::Zilla::Plugin::MakeMaker ();
+use Dist::Zilla::Plugin::ModuleBuild ();
+use Dist::Zilla::Plugin::InstallGuide ();
+use Dist::Zilla::Plugin::ReadmeFromPod ();
+use Dist::Zilla::Plugin::Git::NextVersion ();
+use Dist::Zilla::Plugin::CopyFilesFromBuild ();
+use Dist::Zilla::Plugin::Git::Check ();
+use Dist::Zilla::Plugin::CheckChangesHasContent ();
+use Dist::Zilla::Plugin::CheckExtraTests ();
+use Dist::Zilla::Plugin::TestRelease ();
+use Dist::Zilla::Plugin::ConfirmRelease ();
+use Dist::Zilla::Plugin::UploadToCPAN ();
+use Dist::Zilla::Plugin::NextRelease ();
+use Dist::Zilla::Plugin::Git::Commit ();
+use Dist::Zilla::Plugin::Git::Tag ();
+use Dist::Zilla::Plugin::Git::Push ();
+
 
 sub configure {
     my $self = shift;
@@ -57,6 +101,9 @@ sub configure {
 
     # FileMunger
     $self->add_plugins(
+        qw(
+          PkgVersion
+        ),
         [
             Authority => {
                 authority   => 'cpan:AJGB',
@@ -163,7 +210,7 @@ Dist::Zilla::PluginBundle::AJGB - Dist::Zilla plugins for AJGB
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -197,6 +244,7 @@ This is the plugin bundle for AJGB. It's an equivalent to:
     [PruneCruft]
     [ManifestSkip]
 
+    [PkgVersion]
     [Authority]
     authority = cpan:AJGB
     do_metadata = 1
